%    This file is part of the psPack simulation package from the
%    doctoral dissertation "A DAE Formulation for Multi-Zone
%    Application to CVCP Engines" by Per Öberg. 
%    The dissertation is available at 
%    http://urn.kb.se/resolve?urn=urn:nbn:se:liu:diva-18120
%
%    Copyright (C) 2013  Per Öberg <per.oberg@liu.se>
%
%    This program is free software; you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation; either version 2 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License along
%    with this program; if not, write to the Free Software Foundation, Inc.,
%    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

% Convert sim-data
psSimResult.psSimOut = psSimOut;
psSimResult.psSimStruct = psSimStruct;
psSimResult.psResampled = psConvertSimOutput(psSimOut,psSimStruct);

% Find events (for example Start of Combustion - SOC or end of combustion
% - EOC)
events =[];
events.eventCa = [];
events = psValveEvents(events); 
events = psVibeEvents(events);
eventNames = fieldnames(rmfield(events,'eventCa'));

eventsCa = [];
for ii = 1:length(eventNames)
    eventsCa = [eventsCa; events.(eventNames{ii})];
end    
[eventsCa sortIndx] = sort(eventsCa);

eventNames = eventNames(sortIndx);


% Make figure
figure(79);
set(79,'PaperPositionMode','Auto')
figPos = get(79,'Position');
figPos(3:4) = [420 300]*1.5;
set(79,'Position',figPos);
fontSize = 8;
clf


% Plot pressure data
hold on
plot(psSimResult.psResampled.lastTwoCycles.theta, ...
     psSimResult.psResampled.lastTwoCycles.p,...
     psSimResult.psResampled.lastTwoCycles.theta, ...
     psSimResult.psResampled.lastTwoCycles.pIM,...
     psSimResult.psResampled.lastTwoCycles.theta, ...
     psSimResult.psResampled.lastTwoCycles.pEM)
legend('pCyl 1','pCyl 2','pCyl 3',' pCyl 4','IM','EM')
h = gca;
ylabel('Pressure [Pa]')
xlabel('Ca Events')

set(h,'XTickLabel',eventNames)
set(h,'XTick',[eventsCa' eventsCa'+4*pi]) 
set(h,'FontSize',fontSize)
grid on

axis([0 8*pi -1e3 inf])


