%    This file is part of the psPack simulation package from the
%    doctoral dissertation "A DAE Formulation for Multi-Zone
%    Application to CVCP Engines" by Per Öberg. 
%    The dissertation is available at 
%    http://urn.kb.se/resolve?urn=urn:nbn:se:liu:diva-18120
%
%    Copyright (C) 2013  Per Öberg <per.oberg@liu.se>
%
%    This program is free software; you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation; either version 2 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License along
%    with this program; if not, write to the Free Software Foundation, Inc.,
%    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

function X0out = psInitGasexchange(theta,Xend)

global psSimStruct
K = psSimStruct.psThermProp.K;
if psSimStruct.psSimPar.giveWarnings
    disp('---')
    disp('Initializing gas exchange phase')
    %disp('-- press enter --')
    %pause
end

% We are coming from Combustion so 
% Xend =  [p,Vb,Tb,Vu,Tu,-Xgc_u-,-Xgc_b-]

%%% Show progressbar
%showProgress();
%-----------------------------
% Get some parameters
%-----------------------------
%AFs = psSimStruct.psThermProp.AFs;
minVFrac = psSimStruct.psSimPar.minVFrac;

%-----------------------------
% Checking for fresh start
%-----------------------------
if nargin < 2
    if psSimStruct.psSimPar.giveWarnings
        disp('Detected fresh initialization! Reading values from workspace.')
    end
    % Note, this initialization is supposed to occur right after
    % exhaust valve opening. Therefore initial conditions that apply
    % are those of the burned gas.
    % For this case xResIC=1 is a good guess
    p	    = 1e5;%psSimStruct.psModel.pIC_Ge;
    T	    = 350;%psSimStruct.psModel.TIC_Ge;
    Xgc      = psCalcXgc(1,0,1,0.03,1,0.97);%psSimStruct.psModel.XgcIC_Ge;
else
    p    = Xend(01);
    Vb   = Xend(02);
    Tb   = Xend(03);
    Vu   = Xend(04);
    Tu   = Xend(05);
    Xgc_b = Xend(5+(1:K))';
    Xgc_u = Xend(5+K+(1:K))';
    Xgc_b = psCalcMixXgc(Xgc_b,p,Tb);
    Xgc_u = psCalcMixXgc(Xgc_u,p,Tu);
    [p,T,Xgc] = psAdiabaticMix(p,Vb,Tb,Vu,Tu,Xgc_b,Xgc_u,...
                              1e-8);
end


% -----------------------------
% Define new volumes
% -----------------------------
%Vtot = Vb+Vu; 
V = psVolume(theta); % Fix for driftoff from psVolume

X0out = [p;V;T;Xgc(:)];
