%    This file is part of the psPack simulation package from the
%    doctoral dissertation "A DAE Formulation for Multi-Zone
%    Application to CVCP Engines" by Per Öberg. 
%    The dissertation is available at 
%    http://urn.kb.se/resolve?urn=urn:nbn:se:liu:diva-18120
%
%    Copyright (C) 2013  Per Öberg <per.oberg@liu.se>
%
%    This program is free software; you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation; either version 2 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License along
%    with this program; if not, write to the Free Software Foundation, Inc.,
%    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot the result
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Convert sim-data
psSimResult=psConvertSimOutput(psSimOut,psSimStruct);

% Define events for the X-axis
events = [psSimStruct.psVibe.thetaS psSimStruct.psVibe.thetaE psSimStruct.psSimPar.thetaStop];

eventNames = {'SOC','EOC','EOS'};
[events sortIndx] = sort(events);
eventNames = eventNames(sortIndx);


figure(79);
set(79,'PaperPositionMode','Auto')
figPos = get(79,'Position');
figPos(3:4) = [560/2 420]*1.5;
set(79,'Position',figPos);
fontSize = 8;
clf

% Pressure plot
h = subplot(2,1,1);
hold on
box off
h2 = plot(psSimResult.rawData.theta*180/pi,psSimResult.rawData.pcb,'-');
set (h,'FontSize',fontSize)
set(gca,'XTick',events*180/pi)
set(gca,'XTickLabel',eventNames)
xlabel('Crank Events','FontSize',fontSize)
ylabel('Presure [Pa]','FontSize',fontSize)
title('Pressure','FontSize',fontSize)

% Temperatures
h = subplot(2,1,2);
hold on
box off
combStartInd =find(psSimResult.rawData.theta <=  psSimStruct.psVibe.thetaS,1,'last');
combEndInd = find(psSimResult.rawData.theta >=  psSimStruct.psVibe.thetaE,1,'first');
h2 = plot(psSimResult.rawData.theta(1:combEndInd)*180/pi,psSimResult.rawData.Tu(1:combEndInd),'-');
h3 = plot(psSimResult.rawData.theta(combStartInd:end)*180/pi,psSimResult.rawData.Tb(combStartInd:end),'r-');
set (h,'FontSize',fontSize)
set(gca,'XTick',events*180/pi)
set(gca,'XTickLabel',eventNames)
xlabel('Crank Events','FontSize',fontSize)
ylabel('Temperature [K]','FontSize',fontSize)
title('Temperature','FontSize',fontSize)

